#!/usr/bin/env python

__version__ = "$Revision: 1.3 $"
__author__ = "Peter Hendrickson <pdh@wiredyne.com>"

# License:  This code is in the public domain.  Any of this code may be
#           freely reproduced or adapted, even without mentioning the
#           source.

# Warranty: IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR
#           DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
#           DAMAGES ARISING OUT OF THE USE OF THIS CODE, EVEN IF THE
#           AUTHOR HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
#           THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES,
#           INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#           MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE
#           CODE PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THERE
#           IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
#           SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.

import unittest
import Garbage

class GarbageTest(unittest.TestCase):
    """Test the class Garbage."""

    def testBasic(self):
        """Test normal padding - uses newline for eol."""
        target = 241
        for size in xrange(target + 20):
            payload = "a" * size
            gbg = Garbage.Garbage(padded_size=target)
            if size < 170:
                padded = gbg.padstring(payload)
                self.failUnless(len(padded) == target)
                self.failUnless(padded.startswith(payload))
            else:
                self.failUnlessRaises(Garbage.GarbageError, gbg.padstring,
                                      payload)

    def testDOS(self):
        """Test padding with DOS cr-nl line endings."""
        target = 241
        for size in xrange(target + 20):
            payload = "a" * size
            gbg = Garbage.Garbage(padded_size=target, eol="\r\n")
            if size < 166:
                padded = gbg.padstring(payload)
                self.failUnless(len(padded) == target)
                self.failUnless(padded.startswith(payload))
            else:
                self.failUnlessRaises(Garbage.GarbageError, gbg.padstring,
                                      payload)

    def testOdd(self):
        """Test odd case of short lines and long eol."""
        target = 241
        for size in xrange(target + 20):
            payload = "a" * size
            gbg = Garbage.Garbage(padded_size=target, eol="foobar\n",
                                  line_len=7)
            if size < 146:
                padded = gbg.padstring(payload)
                self.failUnless(len(padded) == target)
                self.failUnless(padded.startswith(payload))
            else:
                self.failUnlessRaises(Garbage.GarbageError, gbg.padstring,
                                      payload)

unittest.main()
